@@ -114,8 +114,20 @@ def populationComparison(self, controller, TailTrackingParameters=0, saveInMatla
   controller.show_frame("AnalysisOutputFolderPopulation")
 
 
-def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbeded):
-
+def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbeded, minNbBendForBoutDetect=3, nbVideosToSave=0):
+  
+  if len(minNbBendForBoutDetect) == 0:
+    minNbBendForBoutDetect = 3
+  else:
+    minNbBendForBoutDetect = int(minNbBendForBoutDetect)
+  
+  if len(nbVideosToSave) == 0:
+    nbVideosToSave = 0
+  else:
+    nbVideosToSave = int(nbVideosToSave)
+  
+  videoSaveFirstTenBouts = True if nbVideosToSave else False
+  
   cur_dir_path = os.path.dirname(os.path.realpath(__file__))
   cur_dir_path = Path(cur_dir_path)
   cur_dir_path = cur_dir_path.parent.parent
@@ -134,7 +146,7 @@ def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbed
     'smoothingFactorDynaParam'          : 0,   # 0.001
     'nbFramesTakenIntoAccount'          : -1, #28,
     'numberOfBendsIncludedForMaxDetect' : -1,
-    'minNbBendForBoutDetect'            : 3, # THIS NEEDS TO BE CHANGED IF FPS IS LOW (default: 3)
+    'minNbBendForBoutDetect'            : minNbBendForBoutDetect,
     'defaultZZoutputFolderPath'         : ZZoutputLocation,
     'tailAngleKinematicParameterCalculation' : 1,
     'getTailAngleSignMultNormalized'    : 1,
@@ -162,9 +174,9 @@ def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbed
     'useAnglesHeading' : False,
     'useAnglesHeadingDisp' : False,
     'useFreqAmpAsymSpeedHeadingDisp' : False,
-    'videoSaveFirstTenBouts' : False,
+    'videoSaveFirstTenBouts' : videoSaveFirstTenBouts,
     'globalParametersCalculations' : True,
-    'nbVideosToSave' : 10,
+    'nbVideosToSave' : nbVideosToSave,
     'resFolder' : os.path.join(os.path.join(cur_dir_path, 'dataAnalysis'),'data/'),
     'nameOfFile' : self.experimentOrganizationExcel.split(".")[0]
   }
@@ -173,7 +185,7 @@ def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbed
   if int(HeadEmbeded):
     clusteringOptions['useAngles'] = True
   # Applies the clustering
-  [allBouts, classifier] = applyClustering(clusteringOptions, 0, os.path.join(os.path.join(cur_dir_path, 'dataAnalysis'),'resultsClustering/'))
+  [allBouts, classifier] = applyClustering(clusteringOptions, 0, os.path.join(os.path.join(cur_dir_path, 'dataAnalysis'),'resultsClustering/'), self.ZZoutputLocation)
   # Saves the classifier
   controller.show_frame("AnalysisOutputFolderClustering")
 
